@@ -18,7 +18,10 @@ int main(int argc, char *argv[]) {
 FILE  *fp;
 int c, interactive = 0;
 char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comment[31]="", fbuf[4];
-unsigned short sig;
+unsigned char sig[2];
+unsigned char genre[1];
+unsigned int g;
+
 
    if (argc < 2 ) /* Only command is given. Short help */ {
 	   printf("%s\r\n  Usage: %s [-h] (-i | -t title -a artist -l album -y year -c comment ) 
@@ -31,16 +34,27 @@ unsigned short sig;
    }
 
    if (!strcmp(argv[1],"-h")) { display_help(); return 0; }
-   if ( !( fp=fopen(argv[argc-1],"rb+") ) ) {
-           perror("Error opening MP3");
-           return 0;
-   }
+   
+   /* if we only want to read out the information, we don't need write
+       +      access... this makes it work as a lister for CD-ROMs. CH 09/99 */
+   if (!strcmp(argv[1],"-v")) { 
+     if ( !( fp=fopen(argv[argc-1],"r") ) ) {
+             perror("Error opening MP3");
+             return 0;
+     }
+   } else {
+     if ( !( fp=fopen(argv[argc-1],"rb+") ) ) {
+             perror("Error opening MP3");
+             return 0;
+     }
+}
 
    /* Let's see if it's an MP3. SMJ 06/1999 */     
 
-   fread(&sig,sizeof(short),1,fp);                         
-   sig &= 0xf0ff;                                                         
-   if(sig != 0xf0ff) {
+   fread(sig,sizeof(sig),1,fp);                         
+   sig[0] &= 0xff;
+   sig[1] &= 0xf0;                                                         
+   if(!((sig[0] == 0xff) && (sig[1] == 0xf0))) {
            fprintf(stderr,"%s is not an MP3 file!\n",argv[argc-1]);        
            return(-1);
    }                                                          
@@ -59,6 +73,7 @@ unsigned short sig;
 	   fread(album,1,30,fp); album[30] = '\0';
 	   fread(year,1,4,fp); year[4] = '\0';
 	   fread(comment,1,30,fp); comment[30] = '\0';
+	   fread(genre,1,1,fp);
 	   /* freads moved the file pointer. Get it back to the beginning of the tag so it 	*
 	    * will be overwritten 								*/
            fseek(fp, -128, SEEK_END);
@@ -73,7 +88,7 @@ unsigned short sig;
    }
   
    /* Let's see what the user wants to do... */
-   while ((c=getopt(argc,argv,"vhit:a:l:y:c:"))!=-1) {
+   while ((c=getopt(argc,argv,"vhit:a:l:y:c:g:"))!=-1) {
 
 	switch(c) {
 		case 'v':
@@ -101,10 +116,14 @@ unsigned short sig;
 		case 'c':
 			strncpy(comment,optarg,TEXT_FIELD_LEN);
 			break;
+		case 'g':
+			sscanf(optarg,"%u",&g);
+			genre[0] = (unsigned char) g;
+			break;
 	}
    }
    /* Interactive mode builds the tag for itself, so... */
-   if ( !interactive ) { buildtag(fullline,title,artist,album,year,comment); }
+   if ( !interactive ) { buildtag(fullline,title,artist,album,year,comment,genre); }
 
    /* Finally! Get it done! */
    fwrite(fullline,1,128,fp);
