@@ -41,7 +41,7 @@ void pad(char *string, int length) {
  * Build the final tag, ready to be inserted into the file
  */
 
-void buildtag(char *buf, char *title, char *artist, char *album, char *year, char *comment) {
+void buildtag(char *buf, char *title, char *artist, char *album, char *year, char *comment, unsigned char *genre) {
 
 	strcpy(buf,"TAG");
 	pad(title,TEXT_FIELD_LEN); 
@@ -54,7 +54,7 @@ void buildtag(char *buf, char *title, char *artist, char *album, char *year, cha
 	strncat(buf,year,INT_FIELD_LEN);
 	pad(comment,TEXT_FIELD_LEN); 
 	strncat(buf,comment,TEXT_FIELD_LEN);
-	strncat(buf,"",1);
+	strncat(buf,genre,1);
 }
 
 /*
@@ -75,6 +75,7 @@ void display_help() {
 	printf("-l	--	Album Name\n");
 	printf("-y	--	Year\n");
 	printf("-c	--	Comment\n\n");
+	printf("-g	--	Genre\n\n");
 	printf("Non-specified fields, if existant, will remain unchanged.\n");
 	printf("Remember: Multiple word fields must be enclosed in \"\" (eg: -t \"A title\")\n\n");
 
