@@ -17,6 +17,6 @@ void CenterText(int line, char *text);
 char *checkinput(int c, char *string, int length);
 void pad(char *string, int length);
 char *curs_addparam(WINDOW *win, int line, int length, char *buf);
-void buildtag(char *buf, char *title, char *artist, char *album, char *year, char *comment);
+void buildtag(char *buf, char *title, char *artist, char *album, char *year, char *comment, unsigned char *genre);
 void display_help();
 void view_tag(FILE *fp);
